#' Multivariate birth-death processes
#'
#' The MultiBD package computes the transition probabilities
#' of several multivariate birth-death processes.
#'
#' @references Ho LST et al. 2016. "Birth(death)/birth-death processes and their computable transition probabilities with statistical applications". In review.
#'
#' @name MultiBD
#' @importFrom RcppParallel RcppParallelLibs
#' @importFrom Rcpp evalCpp
#' @useDynLib MultiBD
"_PACKAGE"
